@@ -21,7 +21,7 @@ _logger.debug("Importing custom API hooks (CA, optional).")
 
 # Technically, this should be unique to the CA. SHA1 will be sufficient as a 
 # default implementation.
-SERIAL_NUMBER_GENERATOR_CB = lambda: 
+SERIAL_NUMBER_GENERATOR_CB = lambda: \
                                 hashlib.sha1(str(time.time())).
                                     hexdigest()
 
